'''
The zodbpickle.pickle module exposes the standard behavior of
the pickle module.
This is backward compatible, but has the effect that by default,
on Python3 you get the fast implementation, while on Python2
you get the slow implementation.

This module is a version that always exposes the fast implementation
of pickling and avoids the need to explicitly touch internals.
'''

'''
Note: We are intentionally using "import *" in this context.
The imported modules define an __all__ variable, which contains
all the names that it wants to export.
So this is a rare case where 'import *' is exactly the right thing to do.
'''

from .pickle_3 import *
# do not share the globals with a slow version
del sys.modules['zodbpickle.pickle_3']
# also make sure that we really have the fast version
from ._pickle import *



from . import _is_pypy
import sys
import types
import unittest

if _is_pypy:
    function_type = types.FunctionType
else:
    function_type = types.BuiltinFunctionType
del sys
del _is_pypy


class TestImportability(unittest.TestCase):

    def test_Pickler(self):
        from zodbpickle.pickle import Pickler
        self.assertIsInstance(Pickler, object)

    def test_Unpickler(self):
        from zodbpickle.pickle import Unpickler
        self.assertIsInstance(Unpickler, object)

    def test_load(self):
        from zodbpickle.pickle import load
        self.assertIsInstance(load, function_type)

    def test_loads(self):
        from zodbpickle.pickle import loads
        self.assertIsInstance(loads, function_type)

    def test_dump(self):
        from zodbpickle.pickle import dump
        self.assertIsInstance(dump, function_type)

    def test_dumps(self):
        from zodbpickle.pickle import dumps
        self.assertIsInstance(dumps, function_type)


def test_suite():
    from .pickle_3_tests import test_suite
    return unittest.TestSuite([
        test_suite(),
        unittest.defaultTestLoader.loadTestsFromName(__name__),
    ])
